@@ -24,11 +24,6 @@
 
 #include "fwts.h"
 
-static char *acpidump_headline(void)
-{
-	return "Dump ACPI tables.";
-}
-
 struct fwts_acpidump_field;
 
 typedef void (*fwts_acpidump_field_func)(fwts_framework *fw, struct fwts_acpidump_field *info, void *data, int offset);
@@ -566,7 +561,7 @@ static void acpidump_fadt(fwts_framework *fw, uint8_t *data, int length)
 		FIELD_BITF("  32 bit PM timer (V1)", 			fwts_acpi_table_fadt, flags, 1, 8),
 		FIELD_BITF("  Docking Capability (V1)", 		fwts_acpi_table_fadt, flags, 1, 9),
 		FIELD_BITF("  Reset Register Supported (V2)", 		fwts_acpi_table_fadt, flags, 1, 10),
-		FIELD_BITF("  Selead Case (V3)", 			fwts_acpi_table_fadt, flags, 1, 11),
+		FIELD_BITF("  Sealed Case (V3)", 			fwts_acpi_table_fadt, flags, 1, 11),
 		FIELD_BITF("  Headless, No Video (V3)", 		fwts_acpi_table_fadt, flags, 1, 12),
 		FIELD_BITF("  Use native instr. after SLP_TYPx (V3)",	fwts_acpi_table_fadt, flags, 1, 13),
 		FIELD_BITF("  PCI_EXP_WAK bits supported (V4)", 	fwts_acpi_table_fadt, flags, 1, 14),
@@ -988,7 +983,7 @@ typedef struct {
 #define acpidump_hest		acpi_dump_raw_table
 #define acpidump_msct		acpi_dump_raw_table
 
-acpidump_table_vec table_vec[] = {
+static acpidump_table_vec table_vec[] = {
 	{ "APIC", 	acpidump_madt, 	1 },
 	{ "BERT", 	acpidump_bert, 	1 },
 	{ "BOOT", 	acpidump_boot, 	1 },
@@ -1021,7 +1016,7 @@ static int acpidump_table(fwts_framework *fw, fwts_acpi_table_info *table)
 	int length;
 	int i;
 
-	data = table->data;
+	data = (uint8_t*)table->data;
 	length = table->length;
 
 	for (i=0; table_vec[i].name != NULL; i++) {
@@ -1052,7 +1047,7 @@ static int acpidump_test1(fwts_framework *fw)
 	fwts_infoonly(fw);
 
 	for (i=0; (fwts_acpi_get_table(fw, i, &table) == FWTS_OK) && (table !=NULL); i++) {
-		fwts_log_info_verbatum(fw, "%s @ %4.4x (%d bytes)", table->name, (uint32_t)table->addr, table->length);
+		fwts_log_info_verbatum(fw, "%s @ %4.4x (%d bytes)", table->name, (uint32_t)table->addr, (int)table->length);
 		fwts_log_info_verbatum(fw, "---------------");
 		acpidump_table(fw, table);
 		fwts_log_nl(fw);
@@ -1068,7 +1063,7 @@ static fwts_framework_minor_test acpidump_tests[] = {
 };
 
 static fwts_framework_ops acpidump_ops = {
-	.headline    = acpidump_headline,
+	.description = "Dump ACPI tables.",
 	.minor_tests = acpidump_tests
 };
 
