@@ -30,11 +30,6 @@
 #include <unistd.h>
 #include <string.h>
 
-static char *dmesg_common_headline(void)
-{
-	return "General dmesg common errors check.";
-}
-
 static fwts_list *klog;
 
 static int dmesg_common_init(fwts_framework *fw)
@@ -59,7 +54,7 @@ static int dmesg_common_deinit(fwts_framework *fw)
 }
 
 static int dmesg_common_test1(fwts_framework *fw)
-{	
+{
 	int errors = 0;
 
 	if (fwts_klog_common_check(fw, NULL, klog, &errors)) {
@@ -82,8 +77,8 @@ static fwts_framework_minor_test dmesg_common_tests[] = {
 };
 
 static fwts_framework_ops dmesg_common_ops = {
-	.headline    = dmesg_common_headline,
-	.init        = dmesg_common_init,	
+	.description = "General dmesg common errors check.",
+	.init        = dmesg_common_init,
 	.deinit      = dmesg_common_deinit,
 	.minor_tests = dmesg_common_tests
 };
