@@ -73,7 +73,7 @@ static ACPI_TABLE_XSDT 		*fwts_acpica_XSDT;
 static ACPI_TABLE_RSDT          *fwts_acpica_RSDT;
 static ACPI_TABLE_RSDP		*fwts_acpica_RSDP;
 static ACPI_TABLE_FADT		*fwts_acpica_FADT;
-static void *			*fwts_acpica_DSDT;
+static void 			*fwts_acpica_DSDT;
 
 static fwts_framework		*fwts_acpica_fw;			/* acpica context copy of fw */
 static int			fwts_acpica_force_sem_timeout;		/* > 0, forces a semaphore timeout */
@@ -131,9 +131,9 @@ void fwts_acpica_simulate_sem_timeout(int timeout)
  *  hash_sem_handle()
  *	generate a simple hash based on semaphore handle
  */
-static int hash_sem_handle(sem_t *sem)
+static unsigned int hash_sem_handle(sem_t *sem)
 {	
-	int i = (int)((long)sem % MAX_SEMAPHORES);
+	unsigned int i = (unsigned int)((unsigned long)sem % MAX_SEMAPHORES);
 	int j;
 
 	for (j=0;j<MAX_SEMAPHORES;j++) {
@@ -152,7 +152,7 @@ static int hash_sem_handle(sem_t *sem)
  */
 static void hash_sem_inc_count(sem_t *sem)
 {
-	int i = hash_sem_handle(sem);
+	unsigned int i = hash_sem_handle(sem);
 	if (i != HASH_FULL) {
 		sem_hash_table[i].sem = sem;
 		sem_hash_table[i].count++;
@@ -165,7 +165,7 @@ static void hash_sem_inc_count(sem_t *sem)
  */
 static void hash_sem_dec_count(sem_t *sem)
 {
-	int i = hash_sem_handle(sem);
+	unsigned int i = hash_sem_handle(sem);
 	if (i != HASH_FULL) {
 		sem_hash_table[i].sem = sem;
 		sem_hash_table[i].count--;
@@ -199,14 +199,11 @@ static ACPI_STATUS fwtsExceptionHandler(ACPI_STATUS AmlStatus, ACPI_NAME Name,
 	char *exception = (char*)AcpiFormatException(AmlStatus);
 
 	if (Name)
-		fwts_log_info(fwts_acpica_fw, "[AcpiExec] Exception %s during execution of method %4.4s", exception, (char*)&Name);
+		fwts_log_info(fwts_acpica_fw, "ACPICA Exception %s during execution of method %4.4s", exception, (char*)&Name);
 	else
-		fwts_log_info(fwts_acpica_fw, "[AcpiExec] Exception %s during execution at module level (table load)", exception);
+		fwts_log_info(fwts_acpica_fw, "ACPICA Exception %s during execution at module level (table load)", exception);
 
-	if (AmlStatus == AE_AML_INFINITE_LOOP)
-		return AmlStatus;
-
-   	return AE_OK;
+	return AmlStatus;
 }
 
 static void fwtsDeviceNotifyHandler(ACPI_HANDLE device, UINT32 value, void *context)
@@ -399,6 +396,28 @@ ACPI_STATUS AcpiOsReadPort(ACPI_IO_ADDRESS addr, UINT32 *value, UINT32 width)
 	return AE_OK;
 }
 
+/*
+ *  AcpiOsReadPciConfiguration()
+ *	Override ACPICA AcpiOsReadPciConfiguration to fake PCI reads
+ */
+ACPI_STATUS AcpiOsReadPciConfiguration(ACPI_PCI_ID *pciid, UINT32 reg, UINT64 *value, UINT32 width)
+{
+	switch (width) {
+    		case 8:
+        		*value = 0x00;
+			break;
+		case 16:
+			*value = 0x0000;
+			break;
+		case 32:
+			*value = 0x00000000;
+			break;
+		default:
+			return AE_BAD_PARAMETER;
+	}
+	return AE_OK;
+}
+
 void AeTableOverride(ACPI_TABLE_HEADER *ExistingTable, ACPI_TABLE_HEADER **NewTable)
 {
     	if (strncmp(ExistingTable->Signature, ACPI_SIG_DSDT, 4) == 0)
@@ -461,23 +480,32 @@ int fwts_acpica_init(fwts_framework *fw)
 		if (fwts_acpi_find_table(fw, "DSDT", 0, &tbl) != FWTS_OK)
 			return FWTS_ERROR;
 		if (tbl) {
-			fwts_acpica_DSDT = tbl->data;
+			fwts_acpica_DSDT = (void *)tbl->data;
 
 			fwts_acpica_FADT->Dsdt = ACPI_PTR_TO_PHYSADDR(tbl->data);
 			if (table->length >= 148)
 				fwts_acpica_FADT->XDsdt = ACPI_PTR_TO_PHYSADDR(tbl->data);
+		} else {
+			fwts_acpica_DSDT = NULL;
+			fwts_acpica_FADT->Dsdt = 0;
+			fwts_acpica_FADT->XDsdt = 0;
 		}
 
 		if (fwts_acpi_find_table(fw, "FACS", 0, &tbl) != FWTS_OK)
 			return FWTS_ERROR;
 		if (tbl) {
+			fwts_acpica_FADT->Facs = ACPI_PTR_TO_PHYSADDR(tbl->data);
 			if (table->length >= 140)
 				fwts_acpica_FADT->XFacs = ACPI_PTR_TO_PHYSADDR(tbl->data);
-			fwts_acpica_FADT->Facs = ACPI_PTR_TO_PHYSADDR(tbl->data);
+		} else {
+			fwts_acpica_FADT->Facs = 0;
+			fwts_acpica_FADT->XFacs = 0;
 		}
 
 		fwts_acpica_FADT->Header.Checksum = 0;
 		fwts_acpica_FADT->Header.Checksum = (UINT8)-AcpiTbChecksum ((void*)fwts_acpica_FADT, table->length);
+	} else {
+		fwts_acpica_FADT = NULL;
 	}
 	
 	/* Clone XSDT, make it point to tables in user address space */
@@ -507,6 +535,8 @@ int fwts_acpica_init(fwts_framework *fw)
 		}
 		fwts_acpica_XSDT->Header.Checksum = 0;
 		fwts_acpica_XSDT->Header.Checksum = (UINT8)-AcpiTbChecksum ((void*)fwts_acpica_XSDT, table->length);
+	} else {
+		fwts_acpica_XSDT = NULL;
 	}
 
 	/* Clone RSDT, make it point to tables in user address space */
@@ -537,6 +567,8 @@ int fwts_acpica_init(fwts_framework *fw)
 		}
 		fwts_acpica_RSDT->Header.Checksum = 0;
 		fwts_acpica_RSDT->Header.Checksum = (UINT8)-AcpiTbChecksum ((void*)fwts_acpica_RSDT, table->length);
+	} else {
+		fwts_acpica_RSDT = NULL;
 	}
 
 	/* Clone RSDP, make it point to tables in user address space */
@@ -550,6 +582,8 @@ int fwts_acpica_init(fwts_framework *fw)
 			fwts_acpica_RSDP->XsdtPhysicalAddress = ACPI_PTR_TO_PHYSADDR(fwts_acpica_XSDT);
 		fwts_acpica_RSDP->RsdtPhysicalAddress = ACPI_PTR_TO_PHYSADDR(fwts_acpica_RSDT);
 		fwts_acpica_RSDP->Checksum = (UINT8)-AcpiTbChecksum ((void*)fwts_acpica_RSDP, ACPI_RSDP_CHECKSUM_LENGTH);
+	} else {
+		fwts_acpica_RSDP = NULL;
 	}
 
 	if (AcpiInitializeTables(Tables, ACPI_MAX_INIT_TABLES, TRUE) != AE_OK) {
@@ -647,7 +681,7 @@ int fwts_acpica_init(fwts_framework *fw)
 
 #define FWTS_ACPICA_FREE(x)	\
 	if (x) {		\
-		fwts_low_free(x);\
+		fwts_low_free(x);	\
 		x = NULL;	\
 	}			\
 
