@@ -24,12 +24,6 @@
 #include <string.h>
 #include <limits.h>
 
-static char *bios_info_headline(void)
-{
-	/* Return the name of the test scenario */
-	return "Gather BIOS DMI information.";
-}
-
 typedef struct {
 	char *dmi_field;
 	char *label;
@@ -65,9 +59,11 @@ static int bios_info_test1(fwts_framework *fw)
 
 	for (i=0; bios_info[i].dmi_field != NULL; i++) {
 		char *data;
-		snprintf(path, sizeof(path), "/sys/class/dmi/id/%s", bios_info[i].dmi_field);
+		snprintf(path, sizeof(path), "/sys/class/dmi/id/%s", 
+			bios_info[i].dmi_field);
 		if ((data = fwts_get(path)) != NULL) {
-			fwts_log_info_verbatum(fw, "%-18.18s: %s", bios_info[i].label, data);
+			fwts_log_info_verbatum(fw, "%-18.18s: %s",
+				bios_info[i].label, data);
 			free(data);
 		}
 	}
@@ -83,7 +79,7 @@ static fwts_framework_minor_test bios_info_tests[] = {
 };
 
 static fwts_framework_ops bios_info_ops = {
-	.headline    = bios_info_headline,
+	.description = "Gather BIOS DMI information.",
 	.minor_tests = bios_info_tests
 };
 
