@@ -42,9 +42,6 @@ fwts_cpuinfo_x86 *fwts_virt_cpuinfo;
 
 static int virt_init(fwts_framework *fw)
 {
-	if (fwts_check_root_euid(fw))
-		return FWTS_ERROR;
-
 	if ((fwts_virt_cpuinfo = fwts_cpu_get_info(0)) == NULL) {
 		fwts_log_error(fw, "Cannot get CPU info");
 		return FWTS_ERROR;
@@ -61,11 +58,6 @@ static int virt_deinit(fwts_framework *fw)
 	return FWTS_OK;
 }
 
-static char *virt_headline(void)
-{
-	return "Test CPU Virtualisation Configuration.";
-}
-
 static int virt_test1(fwts_framework *fw)
 {
 	extern void virt_check_svm(fwts_framework *);
@@ -81,7 +73,7 @@ static int virt_test1(fwts_framework *fw)
 
 	return FWTS_OK;
 }
-	
+
 
 static fwts_framework_minor_test virt_tests[] = {
 	{ virt_test1, "Check CPU Virtualisation Configuration." },
@@ -89,12 +81,12 @@ static fwts_framework_minor_test virt_tests[] = {
 };
 
 static fwts_framework_ops virt_ops = {
-	.headline    = virt_headline,
+	.description = "Test CPU Virtualisation Configuration.",
 	.init        = virt_init,
 	.deinit      = virt_deinit,
 	.minor_tests = virt_tests
 };
 
-FWTS_REGISTER(virt, &virt_ops, FWTS_TEST_ANYTIME, FWTS_BATCH);
+FWTS_REGISTER(virt, &virt_ops, FWTS_TEST_ANYTIME, FWTS_BATCH | FWTS_ROOT_PRIV);
 
 #endif
