@@ -19,21 +19,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
+#include <string.h>
+
 #include "fwts.h"
 
 #ifdef FWTS_ARCH_INTEL
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <sys/mman.h>
-
 static fwts_list *klog;
 
 #define HPET_REG_SIZE  (0x400)
@@ -75,10 +66,10 @@ static void hpet_parse_check_base(fwts_framework *fw, char *table, fwts_list_lin
 			*idx = '\0';
 
 		address_base = strtoul(val, NULL, 0x10);
-			
+
 		if (hpet_base_p != 0) {
 			if (hpet_base_p != address_base)
-				fwts_failed(fw,
+				fwts_failed(fw, LOG_LEVEL_MEDIUM, "HPETBaseMismatch",
 			     		"Mismatched HPET base between %s (%lx) and the kernel (%lx).",
 					table,
 			     		(unsigned long)hpet_base_p, (unsigned long)address_base);
@@ -106,9 +97,9 @@ static void hpet_parse_device_hpet(fwts_framework *fw, char *table, fwts_list_li
 					}
 				}
 				if (strstr(fwts_text_list_text(tmp_item), "DWordMemory") != NULL) {
-					tmp_item = tmp_item->next;	
+					tmp_item = tmp_item->next;
 					if (tmp_item != NULL) {
-						tmp_item = tmp_item->next;	
+						tmp_item = tmp_item->next;
 						if (tmp_item != NULL) {
 							/* HPET section is found, get base */
 							hpet_parse_check_base(fw, table, tmp_item);
@@ -143,9 +134,6 @@ static void hpet_check_base_acpi_table(fwts_framework *fw, char *table, int whic
 
 static int hpet_check_init(fwts_framework *fw)
 {
-	if (fwts_check_root_euid(fw))
-		return FWTS_ERROR;
-
 	if ((klog = fwts_klog_read()) == NULL) {
 		fwts_log_error(fw, "Cannot read kernel log.");
 		return FWTS_ERROR;
@@ -161,11 +149,6 @@ static int hpet_check_deinit(fwts_framework *fw)
 	return FWTS_OK;
 }
 
-static char *hpet_check_headline(void)
-{
-	return "HPET configuration test.";
-}
-
 static int hpet_check_test1(fwts_framework *fw)
 {
 	if (klog == NULL)
@@ -179,13 +162,26 @@ static int hpet_check_test1(fwts_framework *fw)
 		   "IRQ routing and initialization is also verified by the test.");
 
 	fwts_list_foreach(item, klog) {
-		if ((strstr(fwts_text_list_text(item), "ACPI: HPET id:")) != NULL) {
-			char *txt = strstr(fwts_text_list_text(item), "base: ");
-			if (txt)
-				hpet_base_p = strtoul(txt+6,  NULL, 0x10);
-			fwts_log_warning(fw, "HPET driver in the kernel is enabled, inaccurate results follow.");
-			fwts_passed(fw, "Found HPET base %x in kernel log.", (uint32_t)hpet_base_p);
-			break;
+		char *text = fwts_text_list_text(item);
+		/* Old format */
+		if (strstr(text, "ACPI: HPET id:") != NULL) {
+			char *str = strstr(text, "base: ");
+			if (str) {
+				hpet_base_p = strtoul(str+6,  NULL, 0x10);
+				fwts_passed(fw, "Found HPET base %x in kernel log.", (uint32_t)hpet_base_p);
+				break;
+			}
+		}
+		/* New format */
+		/* [    0.277934] hpet0: at MMIO 0xfed00000, IRQs 2, 8, 0 */
+		if ((strstr(text, "hpet") != NULL) &&
+		    (strstr(text, "IRQs") != NULL)) {
+			char *str = strstr(text, "at MMIO ");
+			if (str) {
+				hpet_base_p = strtoul(str+8,  NULL, 0x10);
+				fwts_passed(fw, "Found HPET base %x in kernel log.", (uint32_t)hpet_base_p);
+				break;
+			}
 		}
 	}
 
@@ -199,7 +195,6 @@ static int hpet_check_test1(fwts_framework *fw)
 
 static int hpet_check_test2(fwts_framework *fw)
 {
-	int fd;
 	uint64_t hpet_id;
 	uint32_t vendor_id;
 	uint32_t clk_period;
@@ -209,37 +204,29 @@ static int hpet_check_test2(fwts_framework *fw)
 		return FWTS_SKIP;
 	}
 
-	if ((fd = open("/dev/mem", O_RDONLY)) < 0) {
-		fwts_log_error(fw, "Cannot open /dev/mem.");
-		return FWTS_ERROR;
-	}
-	hpet_base_v =
-	    mmap(NULL, HPET_REG_SIZE, PROT_READ, MAP_SHARED, fd,
-		 hpet_base_p);
-
+	hpet_base_v = fwts_mmap(hpet_base_p, HPET_REG_SIZE);
 	if (hpet_base_v == NULL) {
 		fwts_log_error(fw, "Cannot mmap to /dev/mem.");
-		close(fd);
 		return FWTS_ERROR;
 	}
 
 	hpet_id = *(uint64_t*) hpet_base_v;
 	vendor_id = (hpet_id & 0xffff0000) >> 16;
 
-	
 	if (vendor_id == 0xffff)
-		fwts_failed(fw, "Invalid Vendor ID: %04x - this should be configured.", vendor_id);
+		fwts_failed(fw, LOG_LEVEL_MEDIUM, "HPETVendorId",
+			"Invalid Vendor ID: %04x - this should be configured.", vendor_id);
 	else
 		fwts_passed(fw, "Vendor ID looks sane: %04x.", vendor_id);
 
 	clk_period = hpet_id >> 32;
 	if ((clk_period > MAX_CLK_PERIOD) || (clk_period == 0))
-		fwts_failed(fw, "Invalid clock period %u, must be non-zero and less than 10^8.", clk_period);
+		fwts_failed(fw, LOG_LEVEL_MEDIUM, "HPETClockPeriod",
+			"Invalid clock period %u, must be non-zero and less than 10^8.", clk_period);
 	else
 		fwts_passed(fw, "Valid clock period %u.", clk_period);
 
-	munmap(hpet_base_v, HPET_REG_SIZE);
-	close(fd);
+	(void)fwts_munmap(hpet_base_v, HPET_REG_SIZE);
 
 	return FWTS_OK;
 }
@@ -263,12 +250,12 @@ static fwts_framework_minor_test hpet_check_tests[] = {
 };
 
 static fwts_framework_ops hpet_check_ops = {
-	.headline    = hpet_check_headline,
+	.description = "HPET configuration test.",
 	.init        = hpet_check_init,
 	.deinit      = hpet_check_deinit,
 	.minor_tests = hpet_check_tests
 };
 
-FWTS_REGISTER(hpet_check, &hpet_check_ops, FWTS_TEST_ANYTIME, FWTS_BATCH);
+FWTS_REGISTER(hpet_check, &hpet_check_ops, FWTS_TEST_ANYTIME, FWTS_BATCH | FWTS_ROOT_PRIV);
 
 #endif
