@@ -55,6 +55,7 @@
 #include "fwts_virt.h"
 #include "fwts_formatting.h"
 #include "fwts_summary.h"
+#include "fwts_mmap.h"
 #include "fwts_microcode.h"
 #include "fwts_interactive.h"
 #include "fwts_keymap.h"
@@ -63,6 +64,8 @@
 #include "fwts_oops.h"
 #include "fwts_hwinfo.h"
 #include "fwts_args.h"
+#include "fwts_multiproc.h"
+#include "fwts_ebda.h"
 #include "fwts_alloc.h"
 
 #endif
