@@ -24,8 +24,8 @@
 
 typedef struct {
 	char    name[5];
-	void    *data;
-	int     length;
+	const void *data;
+	size_t	length;
 	int 	which;
 	uint64_t addr;
 } fwts_acpi_table_info;
@@ -36,5 +36,6 @@ int fwts_acpi_free_tables(void);
 int fwts_acpi_find_table(fwts_framework *fw, const char *name, const int which, fwts_acpi_table_info **info);
 int fwts_acpi_find_table_by_addr(fwts_framework *fw, const uint64_t addr, fwts_acpi_table_info **info);
 int fwts_acpi_get_table(fwts_framework *fw, const int index, fwts_acpi_table_info **info);
+uint8_t fwts_acpi_checksum(const uint8_t *data, const int length);
 
 #endif
