@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Canonical
+ * Copyright (C) 2010-2011 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,7 +27,7 @@
 
 int fwts_summary_init(void);
 void fwts_summary_deinit(void);
-int fwts_summary_add(char *test, fwts_log_level level, char *text);
-int fwts_summary_report(fwts_framework *fw);
+int fwts_summary_add(const char *test, fwts_log_level level, char *text);
+int fwts_summary_report(fwts_framework *fw, fwts_list *test_list);
 
 #endif
