@@ -62,7 +62,7 @@ static fwts_option fwts_framework_options[] = {
 	{ "force-clean", 	"f",  0, "Force a clean results log file." },
 	{ "version", 		"v",  0, "Show version (" FWTS_VERSION ")." },
 	{ "dump", 		"d",  0, "Dump out dmesg, dmidecode, lspci, ACPI tables to logs." },
-	{ "table-path", 	"T:", 1, "Path to ACPI tables dumped by acpidump and then acpixtract, e.g. --table-path=/some/path/to/acpidumps" },
+	{ "table-path", 	"t:", 1, "Path to ACPI tables dumped by acpidump and then acpixtract, e.g. --table-path=/some/path/to/acpidumps" },
 	{ "batch-experimental", "",   0, "Run Batch Experimental tests." },
 	{ "interactive-experimental", "", 0, "Just run Interactive Experimental tests." },
 	{ "power-states", 	"P",  0, "Test S3, S4 power states." },
@@ -80,20 +80,6 @@ static fwts_option fwts_framework_options[] = {
 	{ NULL, NULL, 0, NULL }
 };
 
-enum {
-	FWTS_PASSED_TEXT,
-	FWTS_FAILED_TEXT,
-	FWTS_FAILED_LOW_TEXT,
-	FWTS_FAILED_HIGH_TEXT,
-	FWTS_FAILED_MEDIUM_TEXT,
-	FWTS_FAILED_CRITICAL_TEXT,
-	FWTS_WARNING_TEXT,
-	FWTS_ERROR_TEXT,
-	FWTS_ADVICE_TEXT,
-	FWTS_SKIPPED_TEXT,
-	FWTS_ABORTED_TEXT,
-};
-
 static fwts_list fwts_framework_test_list = FWTS_LIST_INIT;
 
 typedef struct {
@@ -112,17 +98,18 @@ static const char *fwts_copyright[] = {
 };
 
 static fwts_framework_setting fwts_framework_settings[] = {
-	{ ID_NAME(FWTS_PASSED_TEXT),		"PASSED",  NULL },
-	{ ID_NAME(FWTS_FAILED_TEXT),		"FAILED",  NULL },
-	{ ID_NAME(FWTS_FAILED_LOW_TEXT),	"FAILED_LOW", NULL },
-	{ ID_NAME(FWTS_FAILED_HIGH_TEXT),	"FAILED_HIGH", NULL },
-	{ ID_NAME(FWTS_FAILED_MEDIUM_TEXT),	"FAILED_MEDIUM", NULL },
-	{ ID_NAME(FWTS_FAILED_CRITICAL_TEXT),	"FAILED_CRITICAL", NULL },
-	{ ID_NAME(FWTS_WARNING_TEXT),		"WARNING", NULL },
-	{ ID_NAME(FWTS_ERROR_TEXT),		"ERROR",   NULL },
-	{ ID_NAME(FWTS_ADVICE_TEXT),		"ADVICE",  NULL },
-	{ ID_NAME(FWTS_SKIPPED_TEXT),		"SKIPPED", NULL },
-	{ ID_NAME(FWTS_ABORTED_TEXT),		"ABORTED", NULL },
+	{ ID_NAME(FWTS_FRAMEWORK_PASSED),		"PASSED",  NULL },
+	{ ID_NAME(FWTS_FRAMEWORK_FAILED),		"FAILED",  NULL },
+	{ ID_NAME(FWTS_FRAMEWORK_FAILED_LOW),		"FAILED_LOW", NULL },
+	{ ID_NAME(FWTS_FRAMEWORK_FAILED_HIGH),		"FAILED_HIGH", NULL },
+	{ ID_NAME(FWTS_FRAMEWORK_FAILED_MEDIUM),	"FAILED_MEDIUM", NULL },
+	{ ID_NAME(FWTS_FRAMEWORK_FAILED_CRITICAL),	"FAILED_CRITICAL", NULL },
+	{ ID_NAME(FWTS_FRAMEWORK_WARNING),		"WARNING", NULL },
+	{ ID_NAME(FWTS_FRAMEWORK_ERROR),		"ERROR",   NULL },
+	{ ID_NAME(FWTS_FRAMEWORK_ADVICE),		"ADVICE",  NULL },
+	{ ID_NAME(FWTS_FRAMEWORK_SKIPPED),		"SKIPPED", NULL },
+	{ ID_NAME(FWTS_FRAMEWORK_ABORTED),		"ABORTED", NULL },
+	{ ID_NAME(FWTS_FRAMEWORK_INFOONLY),		"INFO", NULL },
 };
 
 /*
@@ -148,7 +135,7 @@ void fwts_framework_test_add(const char *name,
 {
 	fwts_framework_test *new_test;
 
-	if (flags & ~FWTS_RUN_ALL_FLAGS) {
+	if (flags & ~(FWTS_RUN_ALL_FLAGS | FWTS_ROOT_PRIV)) {
 		fprintf(stderr, "Test %s flags must be FWTS_BATCH, FWTS_INTERACTIVE, FWTS_BATCH_EXPERIMENTAL, \n"
 			        "FWTS_INTERACTIVE_EXPERIMENTAL or FWTS_POWER_STATES, got %x\n", name, flags);
 		exit(EXIT_FAILURE);
@@ -285,7 +272,8 @@ static void fwts_framework_show_tests(fwts_framework *fw, bool full)
 						total += test->ops->total_tests;
 					}
 					else {
-						printf(" %-13.13s %s\n", test->name, test->ops->headline());
+						printf(" %-13.13s %s\n", test->name, 
+							test->ops->description ? test->ops->description : "");
 					}
 				}
 			}
@@ -389,15 +377,12 @@ void fwts_framework_minor_test_progress(fwts_framework *fw, const int percent, c
 
 	/* Feedback required? */
 	if (fw->show_progress) {
-		int percent;
 		char buf[1024];
 		char truncbuf[256];
 
 		snprintf(buf, sizeof(buf), "%s %s",fw->current_minor_test_name, message);
 		fwts_framework_strtrunc(truncbuf, buf, width-9);
 
-		percent = (100 * (fw->current_minor_test_num-1) / fw->current_major_test->ops->total_tests) +
-			  (fw->minor_test_progress / fw->current_major_test->ops->total_tests);
 		fprintf(stderr, "  %-*.*s: %3.0f%%\r", width-9, width-9, truncbuf, progress);
 		fflush(stderr);
 	}
@@ -411,7 +396,8 @@ void fwts_framework_minor_test_progress(fwts_framework *fw, const int percent, c
 		fprintf(stdout, "XXX\n");
 		fprintf(stdout, "%d\n", (int)progress);
 		fprintf(stdout, "So far: %s\n\n", buffer);
-		fprintf(stdout, "%s\n\n", fw->current_major_test->ops->headline());
+		fprintf(stdout, "%s\n\n", fw->current_major_test->ops->description ? 
+			fw->current_major_test->ops->description : "");
 		fprintf(stdout, "Running test #%d: %s\n",
 			fw->current_major_test_num,
 			fw->current_minor_test_name);
@@ -485,25 +471,25 @@ static int fwts_framework_test_summary(fwts_framework *fw)
 
 	if (fw->flags & FWTS_FRAMEWORK_FLAGS_STDOUT_SUMMARY) {
 		if (results->aborted > 0)
-			printf("%s\n", fwts_framework_get_env(FWTS_ABORTED_TEXT));
+			printf("%s\n", fwts_framework_get_env(FWTS_FRAMEWORK_ABORTED));
 		else if (results->skipped > 0)
-			printf("%s\n", fwts_framework_get_env(FWTS_SKIPPED_TEXT));
+			printf("%s\n", fwts_framework_get_env(FWTS_FRAMEWORK_SKIPPED));
 		else if (results->failed > 0) {
 			/* We intentionally report the highest logged error level */
 			if (fw->failed_level & LOG_LEVEL_CRITICAL)
-				printf("%s\n", fwts_framework_get_env(FWTS_FAILED_CRITICAL_TEXT));
+				printf("%s\n", fwts_framework_get_env(FWTS_FRAMEWORK_FAILED_CRITICAL));
 			else if (fw->failed_level & LOG_LEVEL_HIGH)
-				printf("%s\n", fwts_framework_get_env(FWTS_FAILED_HIGH_TEXT));
+				printf("%s\n", fwts_framework_get_env(FWTS_FRAMEWORK_FAILED_HIGH));
 			else if (fw->failed_level & LOG_LEVEL_MEDIUM)
-				printf("%s\n", fwts_framework_get_env(FWTS_FAILED_MEDIUM_TEXT));
+				printf("%s\n", fwts_framework_get_env(FWTS_FRAMEWORK_FAILED_MEDIUM));
 			else if (fw->failed_level & LOG_LEVEL_LOW)
-				printf("%s\n", fwts_framework_get_env(FWTS_FAILED_LOW_TEXT));
-			else printf("%s\n", fwts_framework_get_env(FWTS_FAILED_TEXT));
+				printf("%s\n", fwts_framework_get_env(FWTS_FRAMEWORK_FAILED_LOW));
+			else printf("%s\n", fwts_framework_get_env(FWTS_FRAMEWORK_FAILED));
 		}
 		else if (results->warning > 0)
-			printf("%s\n", fwts_framework_get_env(FWTS_WARNING_TEXT));
+			printf("%s\n", fwts_framework_get_env(FWTS_FRAMEWORK_WARNING));
 		else
-			printf("%s\n", fwts_framework_get_env(FWTS_PASSED_TEXT));
+			printf("%s\n", fwts_framework_get_env(FWTS_FRAMEWORK_PASSED));
 	}
 
 	if (!(fw->flags & FWTS_FRAMEWORK_FLAGS_LP_TAGS))
@@ -525,6 +511,7 @@ static int fwts_framework_total_summary(fwts_framework *fw)
 static int fwts_framework_run_test(fwts_framework *fw, const int num_tests, fwts_framework_test *test)
 {		
 	fwts_framework_minor_test *minor_test;	
+	int ret;
 
 	fw->current_major_test = test;
 	fw->current_minor_test_name = "";
@@ -547,52 +534,56 @@ static int fwts_framework_run_test(fwts_framework *fw, const int num_tests, fwts
 	if (!(test->flags & FWTS_UTILS))
 		fw->print_summary = 1;
 
-	if (test->ops->headline) {
-		fwts_log_heading(fw, "%s", test->ops->headline());
+	if (test->ops->description) {
+		fwts_log_heading(fw, "%s", test->ops->description);
 		fwts_framework_underline(fw,'-');
 		if (fw->show_progress) {
 			char buf[70];
-			fwts_framework_strtrunc(buf, test->ops->headline(), sizeof(buf));
+			fwts_framework_strtrunc(buf, test->ops->description, sizeof(buf));
 			fprintf(stderr, "Test: %-70.70s\n", buf);
 		}
 	}
 
 	fwts_framework_minor_test_progress(fw, 0, "");
 
-	if (test->ops->init) {
-		int ret;
-		if ((ret = test->ops->init(fw)) != FWTS_OK) {
-			/* Init failed or skipped, so abort */
-			if (ret == FWTS_SKIP) {
-				for (minor_test = test->ops->minor_tests; *minor_test->test_func != NULL; minor_test++) {
-					fw->current_major_test->results.skipped++;
-					fw->total.skipped++;
-				}
-				if (fw->show_progress) {
-					fwts_framework_minor_test_progress_clear_line();
-					fprintf(stderr, " Test skipped.\n");
-				}
-			} else {
-				fwts_log_error(fw, "Aborted test, initialisation failed.");
-				for (minor_test = test->ops->minor_tests; *minor_test->test_func != NULL; minor_test++) {
-					fw->current_major_test->results.aborted++;
-					fw->total.aborted++;
-				}
-				if (fw->show_progress) {
-					fwts_framework_minor_test_progress_clear_line();
-					fprintf(stderr, " Test aborted.\n");
-				}
-			}
-			goto done;
+	if ((test->flags & FWTS_ROOT_PRIV) &&
+	    (fwts_check_root_euid(fw) != FWTS_OK)) {
+		fwts_log_error(fw, "Aborted test, insufficient privilege.");
+		fw->current_major_test->results.aborted += test->ops->total_tests;
+		fw->total.aborted += test->ops->total_tests;
+		if (fw->show_progress) {
+			fwts_framework_minor_test_progress_clear_line();
+			fprintf(stderr, " Test aborted.\n");
 		}
+		goto done;
+	}
+
+	if ((test->ops->init) && 
+	    ((ret = test->ops->init(fw)) != FWTS_OK)) {
+		char *msg = NULL;
+
+		/* Init failed or skipped, so abort */
+		if (ret == FWTS_SKIP) {
+			fw->current_major_test->results.skipped += test->ops->total_tests;
+			fw->total.skipped += test->ops->total_tests;
+			msg = "Test skipped.";
+		} else {
+			fwts_log_error(fw, "Aborted test, initialisation failed.");
+			fw->current_major_test->results.aborted += test->ops->total_tests;
+			fw->total.aborted += test->ops->total_tests;
+			msg = "Test aborted.";
+		}
+		if (fw->show_progress) {
+			fwts_framework_minor_test_progress_clear_line();
+			fprintf(stderr, " %s.\n", msg);
+		}
+		goto done;
 	}
 
 	for (minor_test = test->ops->minor_tests; 
 		*minor_test->test_func != NULL; 
 		minor_test++, fw->current_minor_test_num++) {
 
-		int ret;
-
 		fw->current_minor_test_name = minor_test->name;
 
 		fwts_results_zero(&fw->minor_tests);
@@ -607,10 +598,8 @@ static int fwts_framework_run_test(fwts_framework *fw, const int num_tests, fwts
 
 		/* Something went horribly wrong, abort all other tests too */
 		if (ret == FWTS_ABORTED)  {
-			for (; *minor_test->test_func != NULL; minor_test++) {
-				fw->current_major_test->results.aborted++;
-				fw->total.aborted++;
-			}
+			int aborted = test->ops->total_tests - (fw->current_minor_test_num - 1);
+			fw->current_major_test->results.aborted += aborted;
 			break;
 		}
 		fwts_framework_minor_test_progress(fw, 100, "");
@@ -683,119 +672,55 @@ static fwts_framework_test *fwts_framework_test_find(fwts_framework *fw, const c
 }
 
 /*
- *  fwts_framework_advice()
- *	log advice message
+ *  fwts_framework_log()
+ *	log a test result
  */
-void fwts_framework_advice(fwts_framework *fw, const char *fmt, ...)
+void fwts_framework_log(fwts_framework *fw, 
+	fwts_framework_results result,
+	const char *label,
+	fwts_log_level level,
+	uint32_t *count,
+	const char *fmt, ...)
 {
-	va_list ap;
 	char buffer[4096];
+	char *str = fwts_framework_get_env(result);
 
-	va_start(ap, fmt);
-	vsnprintf(buffer, sizeof(buffer), fmt, ap);
-	fwts_log_nl(fw);
-	fwts_log_printf(fw->results, LOG_RESULT, LOG_LEVEL_NONE, "%s: %s",
-		fwts_framework_get_env(FWTS_ADVICE_TEXT), buffer);
-	fwts_log_nl(fw);
-	va_end(ap);
-}
+	if (fmt) {
+		va_list ap;
 
-/*
- *  fwts_framework_passed()
- *	log a passed test message
- */
-void fwts_framework_passed(fwts_framework *fw, const char *fmt, ...)
-{
-	va_list ap;
-	char buffer[4096];
+		va_start(ap, fmt);
+		vsnprintf(buffer, sizeof(buffer), fmt, ap);
+		va_end(ap);
+	} else 
+		*buffer = '\0';
 
-	va_start(ap, fmt);
-	vsnprintf(buffer, sizeof(buffer), fmt, ap);
-	fw->minor_tests.passed++;
-	fwts_log_printf(fw->results, LOG_RESULT, LOG_LEVEL_NONE, "%s: Test %d, %s",
-		fwts_framework_get_env(FWTS_PASSED_TEXT), fw->current_minor_test_num, buffer);
-	va_end(ap);
-}
+	if (count)
+		(*count)++;
 
-/*
- *  fwts_framework_failed()
- *	log a failed test message
- */
-void fwts_framework_failed(fwts_framework *fw, fwts_log_level level, const char *fmt, ...)
-{
-	va_list ap;
-	char buffer[4096];
-
-	fw->failed_level |= level;
-
-	va_start(ap, fmt);
-	vsnprintf(buffer, sizeof(buffer), fmt, ap);
-	fwts_summary_add(fw->current_major_test->name, level, buffer);
-	fw->minor_tests.failed++;
-	fwts_log_printf(fw->results, LOG_RESULT, level, "%s [%s]: Test %d, %s",
-		fwts_framework_get_env(FWTS_FAILED_TEXT), fwts_log_level_to_str(level), fw->current_minor_test_num, buffer);
-	va_end(ap);
-}
-
-/*
- *  fwts_framework_warning()
- *	log a warning message
- */
-void fwts_framework_warning(fwts_framework *fw, const char *fmt, ...)
-{
-	va_list ap;
-	char buffer[1024];
-
-	va_start(ap, fmt);
-	vsnprintf(buffer, sizeof(buffer), fmt, ap);
-	fw->minor_tests.warning++;
-	fwts_log_printf(fw->results, LOG_RESULT, LOG_LEVEL_MEDIUM, "%s: Test %d, %s",
-		fwts_framework_get_env(FWTS_WARNING_TEXT), fw->current_minor_test_num, buffer);
-	va_end(ap);
-}
-
-/*
- *  fwts_framework_skipped()
- *	log a skipped test message
- */
-void fwts_framework_skipped(fwts_framework *fw, const char *fmt, ...)
-{
-	va_list ap;
-	char buffer[1024];
-
-	va_start(ap, fmt);
-	vsnprintf(buffer, sizeof(buffer), fmt, ap);
-	fw->minor_tests.skipped++;
-	fwts_log_printf(fw->results, LOG_RESULT, LOG_LEVEL_MEDIUM, "%s: Test %d, %s",
-		fwts_framework_get_env(FWTS_SKIPPED_TEXT), fw->current_minor_test_num, buffer);
-	va_end(ap);
-}
-
-/*
- *  fwts_framework_aborted()
- *	log an aborted test message
- */
-void fwts_framework_aborted(fwts_framework *fw, const char *fmt, ...)
-{
-	va_list ap;
-	char buffer[1024];
-
-	va_start(ap, fmt);
-	vsnprintf(buffer, sizeof(buffer), fmt, ap);
-	fw->minor_tests.aborted++;
-	fwts_log_printf(fw->results, LOG_RESULT, LOG_LEVEL_MEDIUM, "%s: Test %d, %s",
-		fwts_framework_get_env(FWTS_ABORTED_TEXT), fw->current_minor_test_num, buffer);
-	va_end(ap);
-}
-
-
-/*
- *  fwts_framework_infoonly()
- *	mark a test as information only 
- */
-void fwts_framework_infoonly(fwts_framework *fw)
-{
-	fw->minor_tests.infoonly++;
+	switch (result) {
+	case FWTS_FRAMEWORK_ADVICE:
+		fwts_log_nl(fw);
+		fwts_log_printf(fw->results, LOG_RESULT, level, "%s: %s", str, buffer);
+		fwts_log_nl(fw);
+		break;
+	case FWTS_FRAMEWORK_FAILED:
+		fw->failed_level |= level;
+		fwts_summary_add(fw->current_major_test->name, level, buffer);
+		fwts_log_printf(fw->results, LOG_RESULT, level, "%s [%s] %s: Test %d, %s",
+			str, fwts_log_level_to_str(level), label, fw->current_minor_test_num, buffer);
+		break;
+	case FWTS_FRAMEWORK_PASSED:
+	case FWTS_FRAMEWORK_WARNING:
+	case FWTS_FRAMEWORK_SKIPPED:
+	case FWTS_FRAMEWORK_ABORTED:
+		fwts_log_printf(fw->results, LOG_RESULT, level, "%s: Test %d, %s",
+			str, fw->current_minor_test_num, buffer);
+		break;
+	case FWTS_FRAMEWORK_INFOONLY:
+		break;	/* no-op */
+	default:
+		break;
+	}
 }
 
 /*
