@@ -30,23 +30,15 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-/* 
+/*
  * This test checks if MaxReadReq is set > 128 for non-internal stuff
  * A too low value hurts performance
  */
 
-static char *maxreadreq_headline(void)
-{
-	return "Checks firmware has set PCI Express MaxReadReq to a higher value on non-motherboard devices.";
-}
-
 static fwts_list *lspci_text;
 
 static int maxreadreq_init(fwts_framework *fw)
 {
-	if (fwts_check_root_euid(fw))
-		return FWTS_ERROR;
-
 	if (fwts_check_executable(fw, fw->lspci, "lspci"))
 		return FWTS_ERROR;
 
@@ -59,7 +51,7 @@ static int maxreadreq_init(fwts_framework *fw)
 		fwts_log_error(fw, "Unexpected empty output from lspci -vvv.");
 		return FWTS_ERROR;
 	}
-	
+
 	return FWTS_OK;
 }
 
@@ -72,7 +64,7 @@ static int maxreadreq_deinit(fwts_framework *fw)
 }
 
 static int maxreadreq_test1(fwts_framework *fw)
-{	
+{
 	int warnings = 0;
 	char current_type[512];
 	char current_device[512];
@@ -89,40 +81,54 @@ static int maxreadreq_test1(fwts_framework *fw)
 
 		if (line[0]!=' ' && line[0] != '\t' && strlen(line)>8) {
 			if (strlen(line) > 500){
-				fwts_log_warning(fw, "Too big pci string would overflow "
-					    "current_device buffer Internal plugin, "
-					    "not a firmware bug.");
+				fwts_log_warning(fw,
+					"Too big pci string would overflow "
+					"current_device buffer Internal "
+					"plugin, not a firmware bug.");
 				break;
 			}
 			snprintf(current_device, sizeof(current_device), "pci://00:%s", line);
 			strncpy(current_type, line+8, 511);
 			c = strchr(current_type, ':');
-			if (c) 
+			if (c)
 				*c='\0';
 		}
 		/* chipset devices are exempt from this check */
 		if (strcmp(current_type, "PCI bridge")==0)
-			continue;		
+			continue;
 		if (strcmp(current_type, "Host bridge")==0)
-			continue;		
+			continue;
 		if (strcmp(current_type, "System peripheral")==0)
-			continue;		
+			continue;
 
 		c = strstr(line, "MaxReadReq ");
 		if (c) {
 			c += 11;
 			val = strtoul(c, NULL, 10);
 			if (val <= 128) {
-				fwts_log_warning(fw, "MaxReadReq for %s is low (%d) [%s].", current_device, val, current_type);
+				fwts_log_warning(fw,
+					"MaxReadReq for %s is low (%d) [%s].",
+					current_device, val, current_type);
 				warnings++;
 			}
 		}
 	}
 
 	if (warnings > 0) {
-		fwts_failed_low(fw, "%d devices have low MaxReadReq settings. " 
-				"Firmware may have configured these too low.",
-				 warnings);
+		fwts_failed(fw, LOG_LEVEL_LOW,
+			"LowMaxReadReq",
+			"%d devices have low MaxReadReq settings. "
+			"Firmware may have configured these too low.",
+			warnings);
+		fwts_advice(fw, 
+			"The MaxReadRequest size is set too low and will affect performance. "
+			"It will provide excellent bus sharing at the cost of bus data transfer "
+			"rates. Although not a critical issue, it may be worth considering setting "
+			"the MaxReadRequest size to 256 or 512 to increase throughput on the PCI "
+			"Express bus. Some drivers (for example the Brocade Fibre Channel driver) "
+			"allow one to override the firmware settings. Where possible, this BIOS "
+			"configuration setting is worth increasing it a little more for better "
+			"performance at a small reduction of bus sharing.");
 		fwts_tag_failed(fw, FWTS_TAG_BIOS);
 	} else
 		fwts_passed(fw, "All devices have MaxReadReq set > 128.");
@@ -136,12 +142,12 @@ static fwts_framework_minor_test maxreadreq_tests[] = {
 };
 
 static fwts_framework_ops maxreadreq_ops = {
-	.headline    = maxreadreq_headline,
-	.init        = maxreadreq_init,	
+	.description = "Checks firmware has set PCI Express MaxReadReq to a higher value on non-motherboard devices.",
+	.init        = maxreadreq_init,
 	.deinit      = maxreadreq_deinit,
 	.minor_tests = maxreadreq_tests
 };
 
-FWTS_REGISTER(maxreadreq, &maxreadreq_ops, FWTS_TEST_ANYTIME, FWTS_BATCH);
+FWTS_REGISTER(maxreadreq, &maxreadreq_ops, FWTS_TEST_ANYTIME, FWTS_BATCH | FWTS_ROOT_PRIV);
 
 #endif
