@@ -509,11 +509,6 @@ static uefidump_info uefidump_info_table[] = {
 	{ NULL, NULL }
 };
 
-static char *uefidump_headline(void)
-{
-	return "Dump UEFI variables.";
-}
-
 static int uefidump_true_filter(const struct dirent *d)
 {
 	return 1;
@@ -591,8 +586,6 @@ static int uefidump_init(fwts_framework *fw)
 		fwts_log_info(fw, "Cannot detect any UEFI firmware. Aborted.");
 		return FWTS_ABORTED;
 	}
-	if (fwts_check_root_euid(fw))	/* need to be root to read data */
-		return FWTS_ERROR;
 
 	return FWTS_OK;
 }
@@ -628,9 +621,9 @@ static fwts_framework_minor_test uefidump_tests[] = {
 };
 
 static fwts_framework_ops uefidump_ops = {
-	.headline    = uefidump_headline,
+	.description = "Dump UEFI variables.",
 	.init        = uefidump_init,
 	.minor_tests = uefidump_tests
 };
 
-FWTS_REGISTER(uefidump, &uefidump_ops, FWTS_TEST_ANYTIME, FWTS_UTILS);
+FWTS_REGISTER(uefidump, &uefidump_ops, FWTS_TEST_ANYTIME, FWTS_UTILS | FWTS_ROOT_PRIV);
